@@ -5,14 +5,14 @@ Information about this python-fedora release
 from fedora import _
 
 NAME = 'python-fedora'
-VERSION = '0.3.28.1'
+VERSION = '0.3.29'
 DESCRIPTION = _('Python modules for interacting with Fedora Services')
 LONG_DESCRIPTION = _('''
 The Fedora Project runs many different services.  These services help us to
 package software, develop new programs, and generally put together the distro.
 This package contains software that helps us do that.
 ''')
-AUTHOR = 'Toshio Kuratomi, Luke Macken'
+AUTHOR = 'Toshio Kuratomi, Luke Macken, Ricky Elrod'
 EMAIL = 'tkuratom@redhat.com'
 COPYRIGHT = '2007-2012 Red Hat, Inc.'
 URL = 'https://fedorahosted.org/python-fedora'
